
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/debug.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x0bDebugProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n$tensorflow/core/protobuf/debug.proto\x12\ntensorflow"\x8e\x01\n\x10DebugTensorWatch\x12\x11\n\tnode_name\x18\x01 \x01(\t\x12\x13\n\x0boutput_slot\x18\x02 \x01(\x05\x12\x11\n\tdebug_ops\x18\x03 \x03(\t\x12\x12\n\ndebug_urls\x18\x04 \x03(\t\x12+\n#tolerate_debug_op_creation_failures\x18\x05 \x01(\x08"\x81\x01\n\x0cDebugOptions\x12=\n\x17debug_tensor_watch_opts\x18\x04 \x03(\x0b2\x1c.tensorflow.DebugTensorWatch\x12\x13\n\x0bglobal_step\x18\n \x01(\x03\x12\x1d\n\x15reset_disk_byte_usage\x18\x0b \x01(\x08"j\n\x12DebuggedSourceFile\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x11\n\tfile_path\x18\x02 \x01(\t\x12\x15\n\rlast_modified\x18\x03 \x01(\x03\x12\r\n\x05bytes\x18\x04 \x01(\x03\x12\r\n\x05lines\x18\x05 \x03(\t"K\n\x13DebuggedSourceFiles\x124\n\x0csource_files\x18\x01 \x03(\x0b2\x1e.tensorflow.DebuggedSourceFileB\x83\x01\n\x18org.tensorflow.frameworkB\x0bDebugProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01b\x06proto3')
_DEBUGTENSORWATCH = _descriptor.Descriptor(name='DebugTensorWatch', full_name='tensorflow.DebugTensorWatch', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='node_name', full_name='tensorflow.DebugTensorWatch.node_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_slot', full_name='tensorflow.DebugTensorWatch.output_slot', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='debug_ops', full_name='tensorflow.DebugTensorWatch.debug_ops', index=2, number=3, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='debug_urls', full_name='tensorflow.DebugTensorWatch.debug_urls', index=3, number=4, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tolerate_debug_op_creation_failures', full_name='tensorflow.DebugTensorWatch.tolerate_debug_op_creation_failures', index=4, number=5, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=53, serialized_end=195)
_DEBUGOPTIONS = _descriptor.Descriptor(name='DebugOptions', full_name='tensorflow.DebugOptions', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='debug_tensor_watch_opts', full_name='tensorflow.DebugOptions.debug_tensor_watch_opts', index=0, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='global_step', full_name='tensorflow.DebugOptions.global_step', index=1, number=10, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='reset_disk_byte_usage', full_name='tensorflow.DebugOptions.reset_disk_byte_usage', index=2, number=11, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=198, serialized_end=327)
_DEBUGGEDSOURCEFILE = _descriptor.Descriptor(name='DebuggedSourceFile', full_name='tensorflow.DebuggedSourceFile', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='host', full_name='tensorflow.DebuggedSourceFile.host', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='file_path', full_name='tensorflow.DebuggedSourceFile.file_path', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='last_modified', full_name='tensorflow.DebuggedSourceFile.last_modified', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bytes', full_name='tensorflow.DebuggedSourceFile.bytes', index=3, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='lines', full_name='tensorflow.DebuggedSourceFile.lines', index=4, number=5, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=329, serialized_end=435)
_DEBUGGEDSOURCEFILES = _descriptor.Descriptor(name='DebuggedSourceFiles', full_name='tensorflow.DebuggedSourceFiles', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='source_files', full_name='tensorflow.DebuggedSourceFiles.source_files', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=437, serialized_end=512)
_DEBUGOPTIONS.fields_by_name['debug_tensor_watch_opts'].message_type = _DEBUGTENSORWATCH
_DEBUGGEDSOURCEFILES.fields_by_name['source_files'].message_type = _DEBUGGEDSOURCEFILE
DESCRIPTOR.message_types_by_name['DebugTensorWatch'] = _DEBUGTENSORWATCH
DESCRIPTOR.message_types_by_name['DebugOptions'] = _DEBUGOPTIONS
DESCRIPTOR.message_types_by_name['DebuggedSourceFile'] = _DEBUGGEDSOURCEFILE
DESCRIPTOR.message_types_by_name['DebuggedSourceFiles'] = _DEBUGGEDSOURCEFILES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
DebugTensorWatch = _reflection.GeneratedProtocolMessageType('DebugTensorWatch', (_message.Message,), {'DESCRIPTOR': _DEBUGTENSORWATCH, '__module__': 'tensorflow.core.protobuf.debug_pb2'})
_sym_db.RegisterMessage(DebugTensorWatch)
DebugOptions = _reflection.GeneratedProtocolMessageType('DebugOptions', (_message.Message,), {'DESCRIPTOR': _DEBUGOPTIONS, '__module__': 'tensorflow.core.protobuf.debug_pb2'})
_sym_db.RegisterMessage(DebugOptions)
DebuggedSourceFile = _reflection.GeneratedProtocolMessageType('DebuggedSourceFile', (_message.Message,), {'DESCRIPTOR': _DEBUGGEDSOURCEFILE, '__module__': 'tensorflow.core.protobuf.debug_pb2'})
_sym_db.RegisterMessage(DebuggedSourceFile)
DebuggedSourceFiles = _reflection.GeneratedProtocolMessageType('DebuggedSourceFiles', (_message.Message,), {'DESCRIPTOR': _DEBUGGEDSOURCEFILES, '__module__': 'tensorflow.core.protobuf.debug_pb2'})
_sym_db.RegisterMessage(DebuggedSourceFiles)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/bfc_memory_map.proto', package='tensorflow', syntax='proto3', serialized_options=b'ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto', create_key=_descriptor._internal_create_key, serialized_pb=b'\n-tensorflow/core/protobuf/bfc_memory_map.proto\x12\ntensorflow"\x92\x01\n\x11MemAllocatorStats\x12\x12\n\nnum_allocs\x18\x01 \x01(\x03\x12\x14\n\x0cbytes_in_use\x18\x02 \x01(\x03\x12\x19\n\x11peak_bytes_in_use\x18\x03 \x01(\x03\x12\x1a\n\x12largest_alloc_size\x18\x04 \x01(\x03\x12\x1c\n\x14fragmentation_metric\x18\x05 \x01(\x02"\xae\x01\n\x08MemChunk\x12\x0f\n\x07address\x18\x01 \x01(\x04\x12\x0c\n\x04size\x18\x02 \x01(\x03\x12\x16\n\x0erequested_size\x18\x03 \x01(\x03\x12\x0b\n\x03bin\x18\x04 \x01(\x05\x12\x0f\n\x07op_name\x18\x05 \x01(\t\x12\x16\n\x0efreed_at_count\x18\x06 \x01(\x04\x12\x14\n\x0caction_count\x18\x07 \x01(\x04\x12\x0e\n\x06in_use\x18\x08 \x01(\x08\x12\x0f\n\x07step_id\x18\t \x01(\x04"\x8b\x01\n\nBinSummary\x12\x0b\n\x03bin\x18\x01 \x01(\x05\x12\x1a\n\x12total_bytes_in_use\x18\x02 \x01(\x03\x12\x1a\n\x12total_bytes_in_bin\x18\x03 \x01(\x03\x12\x1b\n\x13total_chunks_in_use\x18\x04 \x01(\x03\x12\x1b\n\x13total_chunks_in_bin\x18\x05 \x01(\x03".\n\x08SnapShot\x12\x14\n\x0caction_count\x18\x01 \x01(\x04\x12\x0c\n\x04size\x18\x02 \x01(\x03"\xcd\x01\n\nMemoryDump\x12\x16\n\x0eallocator_name\x18\x01 \x01(\t\x12+\n\x0bbin_summary\x18\x02 \x03(\x0b2\x16.tensorflow.BinSummary\x12#\n\x05chunk\x18\x03 \x03(\x0b2\x14.tensorflow.MemChunk\x12\'\n\tsnap_shot\x18\x04 \x03(\x0b2\x14.tensorflow.SnapShot\x12,\n\x05stats\x18\x05 \x01(\x0b2\x1d.tensorflow.MemAllocatorStatsBWZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_protob\x06proto3')
_MEMALLOCATORSTATS = _descriptor.Descriptor(name='MemAllocatorStats', full_name='tensorflow.MemAllocatorStats', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='num_allocs', full_name='tensorflow.MemAllocatorStats.num_allocs', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bytes_in_use', full_name='tensorflow.MemAllocatorStats.bytes_in_use', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='peak_bytes_in_use', full_name='tensorflow.MemAllocatorStats.peak_bytes_in_use', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='largest_alloc_size', full_name='tensorflow.MemAllocatorStats.largest_alloc_size', index=3, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='fragmentation_metric', full_name='tensorflow.MemAllocatorStats.fragmentation_metric', index=4, number=5, type=2, cpp_type=6, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=62, serialized_end=208)
_MEMCHUNK = _descriptor.Descriptor(name='MemChunk', full_name='tensorflow.MemChunk', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='address', full_name='tensorflow.MemChunk.address', index=0, number=1, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='size', full_name='tensorflow.MemChunk.size', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='requested_size', full_name='tensorflow.MemChunk.requested_size', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bin', full_name='tensorflow.MemChunk.bin', index=3, number=4, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='op_name', full_name='tensorflow.MemChunk.op_name', index=4, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='freed_at_count', full_name='tensorflow.MemChunk.freed_at_count', index=5, number=6, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='action_count', full_name='tensorflow.MemChunk.action_count', index=6, number=7, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='in_use', full_name='tensorflow.MemChunk.in_use', index=7, number=8, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_id', full_name='tensorflow.MemChunk.step_id', index=8, number=9, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=211, serialized_end=385)
_BINSUMMARY = _descriptor.Descriptor(name='BinSummary', full_name='tensorflow.BinSummary', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='bin', full_name='tensorflow.BinSummary.bin', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_bytes_in_use', full_name='tensorflow.BinSummary.total_bytes_in_use', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_bytes_in_bin', full_name='tensorflow.BinSummary.total_bytes_in_bin', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_chunks_in_use', full_name='tensorflow.BinSummary.total_chunks_in_use', index=3, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_chunks_in_bin', full_name='tensorflow.BinSummary.total_chunks_in_bin', index=4, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=388, serialized_end=527)
_SNAPSHOT = _descriptor.Descriptor(name='SnapShot', full_name='tensorflow.SnapShot', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='action_count', full_name='tensorflow.SnapShot.action_count', index=0, number=1, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='size', full_name='tensorflow.SnapShot.size', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=529, serialized_end=575)
_MEMORYDUMP = _descriptor.Descriptor(name='MemoryDump', full_name='tensorflow.MemoryDump', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='allocator_name', full_name='tensorflow.MemoryDump.allocator_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bin_summary', full_name='tensorflow.MemoryDump.bin_summary', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='chunk', full_name='tensorflow.MemoryDump.chunk', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='snap_shot', full_name='tensorflow.MemoryDump.snap_shot', index=3, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='stats', full_name='tensorflow.MemoryDump.stats', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=578, serialized_end=783)
_MEMORYDUMP.fields_by_name['bin_summary'].message_type = _BINSUMMARY
_MEMORYDUMP.fields_by_name['chunk'].message_type = _MEMCHUNK
_MEMORYDUMP.fields_by_name['snap_shot'].message_type = _SNAPSHOT
_MEMORYDUMP.fields_by_name['stats'].message_type = _MEMALLOCATORSTATS
DESCRIPTOR.message_types_by_name['MemAllocatorStats'] = _MEMALLOCATORSTATS
DESCRIPTOR.message_types_by_name['MemChunk'] = _MEMCHUNK
DESCRIPTOR.message_types_by_name['BinSummary'] = _BINSUMMARY
DESCRIPTOR.message_types_by_name['SnapShot'] = _SNAPSHOT
DESCRIPTOR.message_types_by_name['MemoryDump'] = _MEMORYDUMP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
MemAllocatorStats = _reflection.GeneratedProtocolMessageType('MemAllocatorStats', (_message.Message,), {'DESCRIPTOR': _MEMALLOCATORSTATS, '__module__': 'tensorflow.core.protobuf.bfc_memory_map_pb2'})
_sym_db.RegisterMessage(MemAllocatorStats)
MemChunk = _reflection.GeneratedProtocolMessageType('MemChunk', (_message.Message,), {'DESCRIPTOR': _MEMCHUNK, '__module__': 'tensorflow.core.protobuf.bfc_memory_map_pb2'})
_sym_db.RegisterMessage(MemChunk)
BinSummary = _reflection.GeneratedProtocolMessageType('BinSummary', (_message.Message,), {'DESCRIPTOR': _BINSUMMARY, '__module__': 'tensorflow.core.protobuf.bfc_memory_map_pb2'})
_sym_db.RegisterMessage(BinSummary)
SnapShot = _reflection.GeneratedProtocolMessageType('SnapShot', (_message.Message,), {'DESCRIPTOR': _SNAPSHOT, '__module__': 'tensorflow.core.protobuf.bfc_memory_map_pb2'})
_sym_db.RegisterMessage(SnapShot)
MemoryDump = _reflection.GeneratedProtocolMessageType('MemoryDump', (_message.Message,), {'DESCRIPTOR': _MEMORYDUMP, '__module__': 'tensorflow.core.protobuf.bfc_memory_map_pb2'})
_sym_db.RegisterMessage(MemoryDump)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import attr_value_pb2 as tensorflow_dot_core_dot_framework_dot_attr__value__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/framework/node_def.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\tNodeProtoP\x01ZOgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/node_def_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n(tensorflow/core/framework/node_def.proto\x12\ntensorflow\x1a*tensorflow/core/framework/attr_value.proto"\xd2\x02\n\x07NodeDef\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02op\x18\x02 \x01(\t\x12\r\n\x05input\x18\x03 \x03(\t\x12\x0e\n\x06device\x18\x04 \x01(\t\x12+\n\x04attr\x18\x05 \x03(\x0b2\x1d.tensorflow.NodeDef.AttrEntry\x12J\n\x17experimental_debug_info\x18\x06 \x01(\x0b2).tensorflow.NodeDef.ExperimentalDebugInfo\x1aB\n\tAttrEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b2\x15.tensorflow.AttrValue:\x028\x01\x1aQ\n\x15ExperimentalDebugInfo\x12\x1b\n\x13original_node_names\x18\x01 \x03(\t\x12\x1b\n\x13original_func_names\x18\x02 \x03(\tB{\n\x18org.tensorflow.frameworkB\tNodeProtoP\x01ZOgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/node_def_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_attr__value__pb2.DESCRIPTOR])
_NODEDEF_ATTRENTRY = _descriptor.Descriptor(name='AttrEntry', full_name='tensorflow.NodeDef.AttrEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.NodeDef.AttrEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.NodeDef.AttrEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=290, serialized_end=356)
_NODEDEF_EXPERIMENTALDEBUGINFO = _descriptor.Descriptor(name='ExperimentalDebugInfo', full_name='tensorflow.NodeDef.ExperimentalDebugInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='original_node_names', full_name='tensorflow.NodeDef.ExperimentalDebugInfo.original_node_names', index=0, number=1, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='original_func_names', full_name='tensorflow.NodeDef.ExperimentalDebugInfo.original_func_names', index=1, number=2, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=358, serialized_end=439)
_NODEDEF = _descriptor.Descriptor(name='NodeDef', full_name='tensorflow.NodeDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.NodeDef.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='op', full_name='tensorflow.NodeDef.op', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input', full_name='tensorflow.NodeDef.input', index=2, number=3, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device', full_name='tensorflow.NodeDef.device', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='attr', full_name='tensorflow.NodeDef.attr', index=4, number=5, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='experimental_debug_info', full_name='tensorflow.NodeDef.experimental_debug_info', index=5, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_NODEDEF_ATTRENTRY, _NODEDEF_EXPERIMENTALDEBUGINFO], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=101, serialized_end=439)
_NODEDEF_ATTRENTRY.fields_by_name['value'].message_type = tensorflow_dot_core_dot_framework_dot_attr__value__pb2._ATTRVALUE
_NODEDEF_ATTRENTRY.containing_type = _NODEDEF
_NODEDEF_EXPERIMENTALDEBUGINFO.containing_type = _NODEDEF
_NODEDEF.fields_by_name['attr'].message_type = _NODEDEF_ATTRENTRY
_NODEDEF.fields_by_name['experimental_debug_info'].message_type = _NODEDEF_EXPERIMENTALDEBUGINFO
DESCRIPTOR.message_types_by_name['NodeDef'] = _NODEDEF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
NodeDef = _reflection.GeneratedProtocolMessageType('NodeDef', (_message.Message,), {'AttrEntry': _reflection.GeneratedProtocolMessageType('AttrEntry', (_message.Message,), {'DESCRIPTOR': _NODEDEF_ATTRENTRY, '__module__': 'tensorflow.core.framework.node_def_pb2'}), 'ExperimentalDebugInfo': _reflection.GeneratedProtocolMessageType('ExperimentalDebugInfo', (_message.Message,), {'DESCRIPTOR': _NODEDEF_EXPERIMENTALDEBUGINFO, '__module__': 'tensorflow.core.framework.node_def_pb2'}), 'DESCRIPTOR': _NODEDEF, '__module__': 'tensorflow.core.framework.node_def_pb2'})
_sym_db.RegisterMessage(NodeDef)
_sym_db.RegisterMessage(NodeDef.AttrEntry)
_sym_db.RegisterMessage(NodeDef.ExperimentalDebugInfo)
DESCRIPTOR._options = None
_NODEDEF_ATTRENTRY._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....tensorflow.core.data.service import common_pb2 as tensorflow_dot_core_dot_data_dot_service_dot_common__pb2
from .....tensorflow.core.framework import tensor_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/data/service/dispatcher.proto', package='tensorflow.data', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n-tensorflow/core/data/service/dispatcher.proto\x12\x0ftensorflow.data\x1a)tensorflow/core/data/service/common.proto\x1a&tensorflow/core/framework/tensor.proto"2\n\x0cTaskProgress\x12\x0f\n\x07task_id\x18\x01 \x01(\x03\x12\x11\n\tcompleted\x18\x02 \x01(\x08"a\n\x16WorkerHeartbeatRequest\x12\x16\n\x0eworker_address\x18\x01 \x01(\t\x12\x18\n\x10transfer_address\x18\x03 \x01(\t\x12\x15\n\rcurrent_tasks\x18\x02 \x03(\x03"_\n\x17WorkerHeartbeatResponse\x12+\n\tnew_tasks\x18\x01 \x03(\x0b2\x18.tensorflow.data.TaskDef\x12\x17\n\x0ftasks_to_delete\x18\x02 \x03(\x03"]\n\x13WorkerUpdateRequest\x12\x16\n\x0eworker_address\x18\x01 \x01(\t\x12.\n\x07updates\x18\x02 \x03(\x0b2\x1d.tensorflow.data.TaskProgress"\x16\n\x14WorkerUpdateResponse"*\n\x14GetDatasetDefRequest\x12\x12\n\ndataset_id\x18\x01 \x01(\x03"I\n\x15GetDatasetDefResponse\x120\n\x0bdataset_def\x18\x01 \x01(\x0b2\x1b.tensorflow.data.DatasetDef"S\n\x0fGetSplitRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\x03\x12\x12\n\nrepetition\x18\x02 \x01(\x03\x12\x1c\n\x14split_provider_index\x18\x03 \x01(\x03"Q\n\x10GetSplitResponse\x12&\n\x05split\x18\x01 \x01(\x0b2\x17.tensorflow.TensorProto\x12\x15\n\rend_of_splits\x18\x02 \x01(\x08"\x13\n\x11GetVersionRequest"%\n\x12GetVersionResponse\x12\x0f\n\x07version\x18\x01 \x01(\x03"K\n\x1bGetOrRegisterDatasetRequest\x12,\n\x07dataset\x18\x01 \x01(\x0b2\x1b.tensorflow.data.DatasetDef"2\n\x1cGetOrRegisterDatasetResponse\x12\x12\n\ndataset_id\x18\x01 \x01(\x03"2\n\x06JobKey\x12\x10\n\x08job_name\x18\x01 \x01(\t\x12\x16\n\x0ejob_name_index\x18\x02 \x01(\x03"\xd1\x01\n\x15GetOrCreateJobRequest\x12\x12\n\ndataset_id\x18\x01 \x01(\x03\x12;\n\x0fprocessing_mode\x18\x02 \x01(\x0e2".tensorflow.data.ProcessingModeDef\x12(\n\x07job_key\x18\x05 \x01(\x0b2\x17.tensorflow.data.JobKey\x12\x17\n\rnum_consumers\x18\x07 \x01(\x03H\x00B\x18\n\x16optional_num_consumersJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05"/\n\x16GetOrCreateJobResponse\x12\x15\n\rjob_client_id\x18\x01 \x01(\x03"P\n\x16MaybeRemoveTaskRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x03\x12\x16\n\x0econsumer_index\x18\x02 \x01(\x03\x12\r\n\x05round\x18\x03 \x01(\x03"*\n\x17MaybeRemoveTaskResponse\x12\x0f\n\x07removed\x18\x01 \x01(\x08"0\n\x17ReleaseJobClientRequest\x12\x15\n\rjob_client_id\x18\x01 \x01(\x03"\x1a\n\x18ReleaseJobClientResponse"\x9b\x01\n\x16ClientHeartbeatRequest\x12\x15\n\rjob_client_id\x18\x01 \x01(\x03\x12\x17\n\rcurrent_round\x18\x02 \x01(\x03H\x00\x12\x17\n\rblocked_round\x18\x04 \x01(\x03H\x01B\x18\n\x16optional_current_roundB\x18\n\x16optional_blocked_roundJ\x04\x08\x03\x10\x04"\x8c\x01\n\x17ClientHeartbeatResponse\x12,\n\ttask_info\x18\x01 \x03(\x0b2\x19.tensorflow.data.TaskInfo\x12\x15\n\x0bblock_round\x18\x03 \x01(\x03H\x00\x12\x14\n\x0cjob_finished\x18\x02 \x01(\x08B\x16\n\x14optional_block_round")\n\nWorkerInfo\x12\x0f\n\x07address\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x03"\x13\n\x11GetWorkersRequest"B\n\x12GetWorkersResponse\x12,\n\x07workers\x18\x01 \x03(\x0b2\x1b.tensorflow.data.WorkerInfo2\xc2\x08\n\x11DispatcherService\x12d\n\x0fWorkerHeartbeat\x12\'.tensorflow.data.WorkerHeartbeatRequest\x1a(.tensorflow.data.WorkerHeartbeatResponse\x12[\n\x0cWorkerUpdate\x12$.tensorflow.data.WorkerUpdateRequest\x1a%.tensorflow.data.WorkerUpdateResponse\x12^\n\rGetDatasetDef\x12%.tensorflow.data.GetDatasetDefRequest\x1a&.tensorflow.data.GetDatasetDefResponse\x12O\n\x08GetSplit\x12 .tensorflow.data.GetSplitRequest\x1a!.tensorflow.data.GetSplitResponse\x12U\n\nGetVersion\x12".tensorflow.data.GetVersionRequest\x1a#.tensorflow.data.GetVersionResponse\x12s\n\x14GetOrRegisterDataset\x12,.tensorflow.data.GetOrRegisterDatasetRequest\x1a-.tensorflow.data.GetOrRegisterDatasetResponse\x12a\n\x0eGetOrCreateJob\x12&.tensorflow.data.GetOrCreateJobRequest\x1a\'.tensorflow.data.GetOrCreateJobResponse\x12d\n\x0fMaybeRemoveTask\x12\'.tensorflow.data.MaybeRemoveTaskRequest\x1a(.tensorflow.data.MaybeRemoveTaskResponse\x12g\n\x10ReleaseJobClient\x12(.tensorflow.data.ReleaseJobClientRequest\x1a).tensorflow.data.ReleaseJobClientResponse\x12d\n\x0fClientHeartbeat\x12\'.tensorflow.data.ClientHeartbeatRequest\x1a(.tensorflow.data.ClientHeartbeatResponse\x12U\n\nGetWorkers\x12".tensorflow.data.GetWorkersRequest\x1a#.tensorflow.data.GetWorkersResponseb\x06proto3', dependencies=[tensorflow_dot_core_dot_data_dot_service_dot_common__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__pb2.DESCRIPTOR])
_TASKPROGRESS = _descriptor.Descriptor(name='TaskProgress', full_name='tensorflow.data.TaskProgress', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='task_id', full_name='tensorflow.data.TaskProgress.task_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='completed', full_name='tensorflow.data.TaskProgress.completed', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=149, serialized_end=199)
_WORKERHEARTBEATREQUEST = _descriptor.Descriptor(name='WorkerHeartbeatRequest', full_name='tensorflow.data.WorkerHeartbeatRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='worker_address', full_name='tensorflow.data.WorkerHeartbeatRequest.worker_address', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='transfer_address', full_name='tensorflow.data.WorkerHeartbeatRequest.transfer_address', index=1, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='current_tasks', full_name='tensorflow.data.WorkerHeartbeatRequest.current_tasks', index=2, number=2, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=201, serialized_end=298)
_WORKERHEARTBEATRESPONSE = _descriptor.Descriptor(name='WorkerHeartbeatResponse', full_name='tensorflow.data.WorkerHeartbeatResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='new_tasks', full_name='tensorflow.data.WorkerHeartbeatResponse.new_tasks', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tasks_to_delete', full_name='tensorflow.data.WorkerHeartbeatResponse.tasks_to_delete', index=1, number=2, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=300, serialized_end=395)
_WORKERUPDATEREQUEST = _descriptor.Descriptor(name='WorkerUpdateRequest', full_name='tensorflow.data.WorkerUpdateRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='worker_address', full_name='tensorflow.data.WorkerUpdateRequest.worker_address', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='updates', full_name='tensorflow.data.WorkerUpdateRequest.updates', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=397, serialized_end=490)
_WORKERUPDATERESPONSE = _descriptor.Descriptor(name='WorkerUpdateResponse', full_name='tensorflow.data.WorkerUpdateResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=492, serialized_end=514)
_GETDATASETDEFREQUEST = _descriptor.Descriptor(name='GetDatasetDefRequest', full_name='tensorflow.data.GetDatasetDefRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dataset_id', full_name='tensorflow.data.GetDatasetDefRequest.dataset_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=516, serialized_end=558)
_GETDATASETDEFRESPONSE = _descriptor.Descriptor(name='GetDatasetDefResponse', full_name='tensorflow.data.GetDatasetDefResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dataset_def', full_name='tensorflow.data.GetDatasetDefResponse.dataset_def', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=560, serialized_end=633)
_GETSPLITREQUEST = _descriptor.Descriptor(name='GetSplitRequest', full_name='tensorflow.data.GetSplitRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='job_id', full_name='tensorflow.data.GetSplitRequest.job_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='repetition', full_name='tensorflow.data.GetSplitRequest.repetition', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='split_provider_index', full_name='tensorflow.data.GetSplitRequest.split_provider_index', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=635, serialized_end=718)
_GETSPLITRESPONSE = _descriptor.Descriptor(name='GetSplitResponse', full_name='tensorflow.data.GetSplitResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='split', full_name='tensorflow.data.GetSplitResponse.split', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='end_of_splits', full_name='tensorflow.data.GetSplitResponse.end_of_splits', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=720, serialized_end=801)
_GETVERSIONREQUEST = _descriptor.Descriptor(name='GetVersionRequest', full_name='tensorflow.data.GetVersionRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=803, serialized_end=822)
_GETVERSIONRESPONSE = _descriptor.Descriptor(name='GetVersionResponse', full_name='tensorflow.data.GetVersionResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='version', full_name='tensorflow.data.GetVersionResponse.version', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=824, serialized_end=861)
_GETORREGISTERDATASETREQUEST = _descriptor.Descriptor(name='GetOrRegisterDatasetRequest', full_name='tensorflow.data.GetOrRegisterDatasetRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dataset', full_name='tensorflow.data.GetOrRegisterDatasetRequest.dataset', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=863, serialized_end=938)
_GETORREGISTERDATASETRESPONSE = _descriptor.Descriptor(name='GetOrRegisterDatasetResponse', full_name='tensorflow.data.GetOrRegisterDatasetResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dataset_id', full_name='tensorflow.data.GetOrRegisterDatasetResponse.dataset_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=940, serialized_end=990)
_JOBKEY = _descriptor.Descriptor(name='JobKey', full_name='tensorflow.data.JobKey', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='job_name', full_name='tensorflow.data.JobKey.job_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='job_name_index', full_name='tensorflow.data.JobKey.job_name_index', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=992, serialized_end=1042)
_GETORCREATEJOBREQUEST = _descriptor.Descriptor(name='GetOrCreateJobRequest', full_name='tensorflow.data.GetOrCreateJobRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dataset_id', full_name='tensorflow.data.GetOrCreateJobRequest.dataset_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='processing_mode', full_name='tensorflow.data.GetOrCreateJobRequest.processing_mode', index=1, number=2, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='job_key', full_name='tensorflow.data.GetOrCreateJobRequest.job_key', index=2, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_consumers', full_name='tensorflow.data.GetOrCreateJobRequest.num_consumers', index=3, number=7, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='optional_num_consumers', full_name='tensorflow.data.GetOrCreateJobRequest.optional_num_consumers', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=1045, serialized_end=1254)
_GETORCREATEJOBRESPONSE = _descriptor.Descriptor(name='GetOrCreateJobResponse', full_name='tensorflow.data.GetOrCreateJobResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='job_client_id', full_name='tensorflow.data.GetOrCreateJobResponse.job_client_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1256, serialized_end=1303)
_MAYBEREMOVETASKREQUEST = _descriptor.Descriptor(name='MaybeRemoveTaskRequest', full_name='tensorflow.data.MaybeRemoveTaskRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='task_id', full_name='tensorflow.data.MaybeRemoveTaskRequest.task_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='consumer_index', full_name='tensorflow.data.MaybeRemoveTaskRequest.consumer_index', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='round', full_name='tensorflow.data.MaybeRemoveTaskRequest.round', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1305, serialized_end=1385)
_MAYBEREMOVETASKRESPONSE = _descriptor.Descriptor(name='MaybeRemoveTaskResponse', full_name='tensorflow.data.MaybeRemoveTaskResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='removed', full_name='tensorflow.data.MaybeRemoveTaskResponse.removed', index=0, number=1, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1387, serialized_end=1429)
_RELEASEJOBCLIENTREQUEST = _descriptor.Descriptor(name='ReleaseJobClientRequest', full_name='tensorflow.data.ReleaseJobClientRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='job_client_id', full_name='tensorflow.data.ReleaseJobClientRequest.job_client_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1431, serialized_end=1479)
_RELEASEJOBCLIENTRESPONSE = _descriptor.Descriptor(name='ReleaseJobClientResponse', full_name='tensorflow.data.ReleaseJobClientResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1481, serialized_end=1507)
_CLIENTHEARTBEATREQUEST = _descriptor.Descriptor(name='ClientHeartbeatRequest', full_name='tensorflow.data.ClientHeartbeatRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='job_client_id', full_name='tensorflow.data.ClientHeartbeatRequest.job_client_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='current_round', full_name='tensorflow.data.ClientHeartbeatRequest.current_round', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='blocked_round', full_name='tensorflow.data.ClientHeartbeatRequest.blocked_round', index=2, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='optional_current_round', full_name='tensorflow.data.ClientHeartbeatRequest.optional_current_round', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[]), _descriptor.OneofDescriptor(name='optional_blocked_round', full_name='tensorflow.data.ClientHeartbeatRequest.optional_blocked_round', index=1, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=1510, serialized_end=1665)
_CLIENTHEARTBEATRESPONSE = _descriptor.Descriptor(name='ClientHeartbeatResponse', full_name='tensorflow.data.ClientHeartbeatResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='task_info', full_name='tensorflow.data.ClientHeartbeatResponse.task_info', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='block_round', full_name='tensorflow.data.ClientHeartbeatResponse.block_round', index=1, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='job_finished', full_name='tensorflow.data.ClientHeartbeatResponse.job_finished', index=2, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='optional_block_round', full_name='tensorflow.data.ClientHeartbeatResponse.optional_block_round', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=1668, serialized_end=1808)
_WORKERINFO = _descriptor.Descriptor(name='WorkerInfo', full_name='tensorflow.data.WorkerInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='address', full_name='tensorflow.data.WorkerInfo.address', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='id', full_name='tensorflow.data.WorkerInfo.id', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1810, serialized_end=1851)
_GETWORKERSREQUEST = _descriptor.Descriptor(name='GetWorkersRequest', full_name='tensorflow.data.GetWorkersRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1853, serialized_end=1872)
_GETWORKERSRESPONSE = _descriptor.Descriptor(name='GetWorkersResponse', full_name='tensorflow.data.GetWorkersResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='workers', full_name='tensorflow.data.GetWorkersResponse.workers', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1874, serialized_end=1940)
_WORKERHEARTBEATRESPONSE.fields_by_name['new_tasks'].message_type = tensorflow_dot_core_dot_data_dot_service_dot_common__pb2._TASKDEF
_WORKERUPDATEREQUEST.fields_by_name['updates'].message_type = _TASKPROGRESS
_GETDATASETDEFRESPONSE.fields_by_name['dataset_def'].message_type = tensorflow_dot_core_dot_data_dot_service_dot_common__pb2._DATASETDEF
_GETSPLITRESPONSE.fields_by_name['split'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_GETORREGISTERDATASETREQUEST.fields_by_name['dataset'].message_type = tensorflow_dot_core_dot_data_dot_service_dot_common__pb2._DATASETDEF
_GETORCREATEJOBREQUEST.fields_by_name['processing_mode'].enum_type = tensorflow_dot_core_dot_data_dot_service_dot_common__pb2._PROCESSINGMODEDEF
_GETORCREATEJOBREQUEST.fields_by_name['job_key'].message_type = _JOBKEY
_GETORCREATEJOBREQUEST.oneofs_by_name['optional_num_consumers'].fields.append(_GETORCREATEJOBREQUEST.fields_by_name['num_consumers'])
_GETORCREATEJOBREQUEST.fields_by_name['num_consumers'].containing_oneof = _GETORCREATEJOBREQUEST.oneofs_by_name['optional_num_consumers']
_CLIENTHEARTBEATREQUEST.oneofs_by_name['optional_current_round'].fields.append(_CLIENTHEARTBEATREQUEST.fields_by_name['current_round'])
_CLIENTHEARTBEATREQUEST.fields_by_name['current_round'].containing_oneof = _CLIENTHEARTBEATREQUEST.oneofs_by_name['optional_current_round']
_CLIENTHEARTBEATREQUEST.oneofs_by_name['optional_blocked_round'].fields.append(_CLIENTHEARTBEATREQUEST.fields_by_name['blocked_round'])
_CLIENTHEARTBEATREQUEST.fields_by_name['blocked_round'].containing_oneof = _CLIENTHEARTBEATREQUEST.oneofs_by_name['optional_blocked_round']
_CLIENTHEARTBEATRESPONSE.fields_by_name['task_info'].message_type = tensorflow_dot_core_dot_data_dot_service_dot_common__pb2._TASKINFO
_CLIENTHEARTBEATRESPONSE.oneofs_by_name['optional_block_round'].fields.append(_CLIENTHEARTBEATRESPONSE.fields_by_name['block_round'])
_CLIENTHEARTBEATRESPONSE.fields_by_name['block_round'].containing_oneof = _CLIENTHEARTBEATRESPONSE.oneofs_by_name['optional_block_round']
_GETWORKERSRESPONSE.fields_by_name['workers'].message_type = _WORKERINFO
DESCRIPTOR.message_types_by_name['TaskProgress'] = _TASKPROGRESS
DESCRIPTOR.message_types_by_name['WorkerHeartbeatRequest'] = _WORKERHEARTBEATREQUEST
DESCRIPTOR.message_types_by_name['WorkerHeartbeatResponse'] = _WORKERHEARTBEATRESPONSE
DESCRIPTOR.message_types_by_name['WorkerUpdateRequest'] = _WORKERUPDATEREQUEST
DESCRIPTOR.message_types_by_name['WorkerUpdateResponse'] = _WORKERUPDATERESPONSE
DESCRIPTOR.message_types_by_name['GetDatasetDefRequest'] = _GETDATASETDEFREQUEST
DESCRIPTOR.message_types_by_name['GetDatasetDefResponse'] = _GETDATASETDEFRESPONSE
DESCRIPTOR.message_types_by_name['GetSplitRequest'] = _GETSPLITREQUEST
DESCRIPTOR.message_types_by_name['GetSplitResponse'] = _GETSPLITRESPONSE
DESCRIPTOR.message_types_by_name['GetVersionRequest'] = _GETVERSIONREQUEST
DESCRIPTOR.message_types_by_name['GetVersionResponse'] = _GETVERSIONRESPONSE
DESCRIPTOR.message_types_by_name['GetOrRegisterDatasetRequest'] = _GETORREGISTERDATASETREQUEST
DESCRIPTOR.message_types_by_name['GetOrRegisterDatasetResponse'] = _GETORREGISTERDATASETRESPONSE
DESCRIPTOR.message_types_by_name['JobKey'] = _JOBKEY
DESCRIPTOR.message_types_by_name['GetOrCreateJobRequest'] = _GETORCREATEJOBREQUEST
DESCRIPTOR.message_types_by_name['GetOrCreateJobResponse'] = _GETORCREATEJOBRESPONSE
DESCRIPTOR.message_types_by_name['MaybeRemoveTaskRequest'] = _MAYBEREMOVETASKREQUEST
DESCRIPTOR.message_types_by_name['MaybeRemoveTaskResponse'] = _MAYBEREMOVETASKRESPONSE
DESCRIPTOR.message_types_by_name['ReleaseJobClientRequest'] = _RELEASEJOBCLIENTREQUEST
DESCRIPTOR.message_types_by_name['ReleaseJobClientResponse'] = _RELEASEJOBCLIENTRESPONSE
DESCRIPTOR.message_types_by_name['ClientHeartbeatRequest'] = _CLIENTHEARTBEATREQUEST
DESCRIPTOR.message_types_by_name['ClientHeartbeatResponse'] = _CLIENTHEARTBEATRESPONSE
DESCRIPTOR.message_types_by_name['WorkerInfo'] = _WORKERINFO
DESCRIPTOR.message_types_by_name['GetWorkersRequest'] = _GETWORKERSREQUEST
DESCRIPTOR.message_types_by_name['GetWorkersResponse'] = _GETWORKERSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TaskProgress = _reflection.GeneratedProtocolMessageType('TaskProgress', (_message.Message,), {'DESCRIPTOR': _TASKPROGRESS, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(TaskProgress)
WorkerHeartbeatRequest = _reflection.GeneratedProtocolMessageType('WorkerHeartbeatRequest', (_message.Message,), {'DESCRIPTOR': _WORKERHEARTBEATREQUEST, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(WorkerHeartbeatRequest)
WorkerHeartbeatResponse = _reflection.GeneratedProtocolMessageType('WorkerHeartbeatResponse', (_message.Message,), {'DESCRIPTOR': _WORKERHEARTBEATRESPONSE, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(WorkerHeartbeatResponse)
WorkerUpdateRequest = _reflection.GeneratedProtocolMessageType('WorkerUpdateRequest', (_message.Message,), {'DESCRIPTOR': _WORKERUPDATEREQUEST, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(WorkerUpdateRequest)
WorkerUpdateResponse = _reflection.GeneratedProtocolMessageType('WorkerUpdateResponse', (_message.Message,), {'DESCRIPTOR': _WORKERUPDATERESPONSE, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(WorkerUpdateResponse)
GetDatasetDefRequest = _reflection.GeneratedProtocolMessageType('GetDatasetDefRequest', (_message.Message,), {'DESCRIPTOR': _GETDATASETDEFREQUEST, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetDatasetDefRequest)
GetDatasetDefResponse = _reflection.GeneratedProtocolMessageType('GetDatasetDefResponse', (_message.Message,), {'DESCRIPTOR': _GETDATASETDEFRESPONSE, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetDatasetDefResponse)
GetSplitRequest = _reflection.GeneratedProtocolMessageType('GetSplitRequest', (_message.Message,), {'DESCRIPTOR': _GETSPLITREQUEST, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetSplitRequest)
GetSplitResponse = _reflection.GeneratedProtocolMessageType('GetSplitResponse', (_message.Message,), {'DESCRIPTOR': _GETSPLITRESPONSE, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetSplitResponse)
GetVersionRequest = _reflection.GeneratedProtocolMessageType('GetVersionRequest', (_message.Message,), {'DESCRIPTOR': _GETVERSIONREQUEST, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetVersionRequest)
GetVersionResponse = _reflection.GeneratedProtocolMessageType('GetVersionResponse', (_message.Message,), {'DESCRIPTOR': _GETVERSIONRESPONSE, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetVersionResponse)
GetOrRegisterDatasetRequest = _reflection.GeneratedProtocolMessageType('GetOrRegisterDatasetRequest', (_message.Message,), {'DESCRIPTOR': _GETORREGISTERDATASETREQUEST, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetOrRegisterDatasetRequest)
GetOrRegisterDatasetResponse = _reflection.GeneratedProtocolMessageType('GetOrRegisterDatasetResponse', (_message.Message,), {'DESCRIPTOR': _GETORREGISTERDATASETRESPONSE, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetOrRegisterDatasetResponse)
JobKey = _reflection.GeneratedProtocolMessageType('JobKey', (_message.Message,), {'DESCRIPTOR': _JOBKEY, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(JobKey)
GetOrCreateJobRequest = _reflection.GeneratedProtocolMessageType('GetOrCreateJobRequest', (_message.Message,), {'DESCRIPTOR': _GETORCREATEJOBREQUEST, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetOrCreateJobRequest)
GetOrCreateJobResponse = _reflection.GeneratedProtocolMessageType('GetOrCreateJobResponse', (_message.Message,), {'DESCRIPTOR': _GETORCREATEJOBRESPONSE, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetOrCreateJobResponse)
MaybeRemoveTaskRequest = _reflection.GeneratedProtocolMessageType('MaybeRemoveTaskRequest', (_message.Message,), {'DESCRIPTOR': _MAYBEREMOVETASKREQUEST, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(MaybeRemoveTaskRequest)
MaybeRemoveTaskResponse = _reflection.GeneratedProtocolMessageType('MaybeRemoveTaskResponse', (_message.Message,), {'DESCRIPTOR': _MAYBEREMOVETASKRESPONSE, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(MaybeRemoveTaskResponse)
ReleaseJobClientRequest = _reflection.GeneratedProtocolMessageType('ReleaseJobClientRequest', (_message.Message,), {'DESCRIPTOR': _RELEASEJOBCLIENTREQUEST, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(ReleaseJobClientRequest)
ReleaseJobClientResponse = _reflection.GeneratedProtocolMessageType('ReleaseJobClientResponse', (_message.Message,), {'DESCRIPTOR': _RELEASEJOBCLIENTRESPONSE, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(ReleaseJobClientResponse)
ClientHeartbeatRequest = _reflection.GeneratedProtocolMessageType('ClientHeartbeatRequest', (_message.Message,), {'DESCRIPTOR': _CLIENTHEARTBEATREQUEST, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(ClientHeartbeatRequest)
ClientHeartbeatResponse = _reflection.GeneratedProtocolMessageType('ClientHeartbeatResponse', (_message.Message,), {'DESCRIPTOR': _CLIENTHEARTBEATRESPONSE, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(ClientHeartbeatResponse)
WorkerInfo = _reflection.GeneratedProtocolMessageType('WorkerInfo', (_message.Message,), {'DESCRIPTOR': _WORKERINFO, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(WorkerInfo)
GetWorkersRequest = _reflection.GeneratedProtocolMessageType('GetWorkersRequest', (_message.Message,), {'DESCRIPTOR': _GETWORKERSREQUEST, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetWorkersRequest)
GetWorkersResponse = _reflection.GeneratedProtocolMessageType('GetWorkersResponse', (_message.Message,), {'DESCRIPTOR': _GETWORKERSRESPONSE, '__module__': 'tensorflow.core.data.service.dispatcher_pb2'})
_sym_db.RegisterMessage(GetWorkersResponse)
_DISPATCHERSERVICE = _descriptor.ServiceDescriptor(name='DispatcherService', full_name='tensorflow.data.DispatcherService', file=DESCRIPTOR, index=0, serialized_options=None, create_key=_descriptor._internal_create_key, serialized_start=1943, serialized_end=3033, methods=[_descriptor.MethodDescriptor(name='WorkerHeartbeat', full_name='tensorflow.data.DispatcherService.WorkerHeartbeat', index=0, containing_service=None, input_type=_WORKERHEARTBEATREQUEST, output_type=_WORKERHEARTBEATRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='WorkerUpdate', full_name='tensorflow.data.DispatcherService.WorkerUpdate', index=1, containing_service=None, input_type=_WORKERUPDATEREQUEST, output_type=_WORKERUPDATERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='GetDatasetDef', full_name='tensorflow.data.DispatcherService.GetDatasetDef', index=2, containing_service=None, input_type=_GETDATASETDEFREQUEST, output_type=_GETDATASETDEFRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='GetSplit', full_name='tensorflow.data.DispatcherService.GetSplit', index=3, containing_service=None, input_type=_GETSPLITREQUEST, output_type=_GETSPLITRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='GetVersion', full_name='tensorflow.data.DispatcherService.GetVersion', index=4, containing_service=None, input_type=_GETVERSIONREQUEST, output_type=_GETVERSIONRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='GetOrRegisterDataset', full_name='tensorflow.data.DispatcherService.GetOrRegisterDataset', index=5, containing_service=None, input_type=_GETORREGISTERDATASETREQUEST, output_type=_GETORREGISTERDATASETRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='GetOrCreateJob', full_name='tensorflow.data.DispatcherService.GetOrCreateJob', index=6, containing_service=None, input_type=_GETORCREATEJOBREQUEST, output_type=_GETORCREATEJOBRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='MaybeRemoveTask', full_name='tensorflow.data.DispatcherService.MaybeRemoveTask', index=7, containing_service=None, input_type=_MAYBEREMOVETASKREQUEST, output_type=_MAYBEREMOVETASKRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='ReleaseJobClient', full_name='tensorflow.data.DispatcherService.ReleaseJobClient', index=8, containing_service=None, input_type=_RELEASEJOBCLIENTREQUEST, output_type=_RELEASEJOBCLIENTRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='ClientHeartbeat', full_name='tensorflow.data.DispatcherService.ClientHeartbeat', index=9, containing_service=None, input_type=_CLIENTHEARTBEATREQUEST, output_type=_CLIENTHEARTBEATRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='GetWorkers', full_name='tensorflow.data.DispatcherService.GetWorkers', index=10, containing_service=None, input_type=_GETWORKERSREQUEST, output_type=_GETWORKERSRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key)])
_sym_db.RegisterServiceDescriptor(_DISPATCHERSERVICE)
DESCRIPTOR.services_by_name['DispatcherService'] = _DISPATCHERSERVICE




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/framework/device_attributes.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x16DeviceAttributesProtosP\x01ZXgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/device_attributes_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n1tensorflow/core/framework/device_attributes.proto\x12\ntensorflow"E\n\x10InterconnectLink\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x10\n\x08strength\x18\x03 \x01(\x05"8\n\nLocalLinks\x12*\n\x04link\x18\x01 \x03(\x0b2\x1c.tensorflow.InterconnectLink"Z\n\x0eDeviceLocality\x12\x0e\n\x06bus_id\x18\x01 \x01(\x05\x12\x11\n\tnuma_node\x18\x02 \x01(\x05\x12%\n\x05links\x18\x03 \x01(\x0b2\x16.tensorflow.LocalLinks"\xac\x01\n\x10DeviceAttributes\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bdevice_type\x18\x02 \x01(\t\x12\x14\n\x0cmemory_limit\x18\x04 \x01(\x03\x12,\n\x08locality\x18\x05 \x01(\x0b2\x1a.tensorflow.DeviceLocality\x12\x13\n\x0bincarnation\x18\x06 \x01(\x06\x12\x1c\n\x14physical_device_desc\x18\x07 \x01(\tB\x91\x01\n\x18org.tensorflow.frameworkB\x16DeviceAttributesProtosP\x01ZXgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/device_attributes_go_proto\xf8\x01\x01b\x06proto3')
_INTERCONNECTLINK = _descriptor.Descriptor(name='InterconnectLink', full_name='tensorflow.InterconnectLink', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='device_id', full_name='tensorflow.InterconnectLink.device_id', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='type', full_name='tensorflow.InterconnectLink.type', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='strength', full_name='tensorflow.InterconnectLink.strength', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=65, serialized_end=134)
_LOCALLINKS = _descriptor.Descriptor(name='LocalLinks', full_name='tensorflow.LocalLinks', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='link', full_name='tensorflow.LocalLinks.link', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=136, serialized_end=192)
_DEVICELOCALITY = _descriptor.Descriptor(name='DeviceLocality', full_name='tensorflow.DeviceLocality', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='bus_id', full_name='tensorflow.DeviceLocality.bus_id', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='numa_node', full_name='tensorflow.DeviceLocality.numa_node', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='links', full_name='tensorflow.DeviceLocality.links', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=194, serialized_end=284)
_DEVICEATTRIBUTES = _descriptor.Descriptor(name='DeviceAttributes', full_name='tensorflow.DeviceAttributes', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.DeviceAttributes.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_type', full_name='tensorflow.DeviceAttributes.device_type', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='memory_limit', full_name='tensorflow.DeviceAttributes.memory_limit', index=2, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='locality', full_name='tensorflow.DeviceAttributes.locality', index=3, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='incarnation', full_name='tensorflow.DeviceAttributes.incarnation', index=4, number=6, type=6, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='physical_device_desc', full_name='tensorflow.DeviceAttributes.physical_device_desc', index=5, number=7, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=287, serialized_end=459)
_LOCALLINKS.fields_by_name['link'].message_type = _INTERCONNECTLINK
_DEVICELOCALITY.fields_by_name['links'].message_type = _LOCALLINKS
_DEVICEATTRIBUTES.fields_by_name['locality'].message_type = _DEVICELOCALITY
DESCRIPTOR.message_types_by_name['InterconnectLink'] = _INTERCONNECTLINK
DESCRIPTOR.message_types_by_name['LocalLinks'] = _LOCALLINKS
DESCRIPTOR.message_types_by_name['DeviceLocality'] = _DEVICELOCALITY
DESCRIPTOR.message_types_by_name['DeviceAttributes'] = _DEVICEATTRIBUTES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
InterconnectLink = _reflection.GeneratedProtocolMessageType('InterconnectLink', (_message.Message,), {'DESCRIPTOR': _INTERCONNECTLINK, '__module__': 'tensorflow.core.framework.device_attributes_pb2'})
_sym_db.RegisterMessage(InterconnectLink)
LocalLinks = _reflection.GeneratedProtocolMessageType('LocalLinks', (_message.Message,), {'DESCRIPTOR': _LOCALLINKS, '__module__': 'tensorflow.core.framework.device_attributes_pb2'})
_sym_db.RegisterMessage(LocalLinks)
DeviceLocality = _reflection.GeneratedProtocolMessageType('DeviceLocality', (_message.Message,), {'DESCRIPTOR': _DEVICELOCALITY, '__module__': 'tensorflow.core.framework.device_attributes_pb2'})
_sym_db.RegisterMessage(DeviceLocality)
DeviceAttributes = _reflection.GeneratedProtocolMessageType('DeviceAttributes', (_message.Message,), {'DESCRIPTOR': _DEVICEATTRIBUTES, '__module__': 'tensorflow.core.framework.device_attributes_pb2'})
_sym_db.RegisterMessage(DeviceAttributes)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....tensorflow.compiler.xla.service import hlo_profile_printer_data_pb2 as tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__profile__printer__data__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/compiler/xla/service/hlo_execution_profile_data.proto', package='xla', syntax='proto3', serialized_options=b'\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n@tensorflow/compiler/xla/service/hlo_execution_profile_data.proto\x12\x03xla\x1a>tensorflow/compiler/xla/service/hlo_profile_printer_data.proto"e\n\x17HloExecutionProfileData\x120\n\x0cprinter_data\x18\x01 \x01(\x0b2\x1a.xla.HloProfilePrinterData\x12\x18\n\x10profile_counters\x18\x02 \x03(\x03B\x03\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__profile__printer__data__pb2.DESCRIPTOR])
_HLOEXECUTIONPROFILEDATA = _descriptor.Descriptor(name='HloExecutionProfileData', full_name='xla.HloExecutionProfileData', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='printer_data', full_name='xla.HloExecutionProfileData.printer_data', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='profile_counters', full_name='xla.HloExecutionProfileData.profile_counters', index=1, number=2, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=137, serialized_end=238)
_HLOEXECUTIONPROFILEDATA.fields_by_name['printer_data'].message_type = tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__profile__printer__data__pb2._HLOPROFILEPRINTERDATA
DESCRIPTOR.message_types_by_name['HloExecutionProfileData'] = _HLOEXECUTIONPROFILEDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
HloExecutionProfileData = _reflection.GeneratedProtocolMessageType('HloExecutionProfileData', (_message.Message,), {'DESCRIPTOR': _HLOEXECUTIONPROFILEDATA, '__module__': 'tensorflow.compiler.xla.service.hlo_execution_profile_data_pb2'})
_sym_db.RegisterMessage(HloExecutionProfileData)
DESCRIPTOR._options = None
